@@ -28,11 +28,11 @@ Spreadsheet::XlateExcel - Trigger a callback subroutine on each row of an Excel
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 SYNOPSIS
 
@@ -73,20 +73,23 @@ For example:
 
 =head2 new
 
-  my $id = Spreadsheet::XlateExcel->new ({ file => 'sheet.xls' })
+  my $id = Spreadsheet::XlateExcel->new ({ file => 'sheet.xls' [, formatter => Spreadsheet::ParseExcel::Fmt->new })
 
 Ye constructor.
 
+Optional formatter attribute is a Spreadsheet::ParseExcel formatter instance.
+Refer to L<http://metacpan.org/module/Spreadsheet::ParseExcel#parse-filename-formatter-> for more about such formatters.
+
 =cut
 
 sub new {
   my ( $class, $option ) = @_;
-  
+
   assert_exists      $option=>'file';
   assert_nonblank    $option->{file};
   assert_defined  -f $option->{file}, 'incoming file exists';
-  
-  bless { book_id => Spreadsheet::ParseExcel->new->parse ( $option->{file} ) }, $class;
+
+  bless { book_id => Spreadsheet::ParseExcel->new->parse ( $option->{file}, $option->{formatter} ) }, $class;
 }
 
 =head2 xlate
@@ -113,7 +116,7 @@ C<on_sheets_unlike>: targets a given book sheet by RE exclusion on name
 
 =item *
 
-C<on_columns_heads_names>: targets columns via a listref of strings
+C<on_columns_heads_named>: targets columns via a listref of strings
 
 =item *
 
@@ -129,12 +132,12 @@ Returns self.
 
 sub xlate {
   my ( $self, $option ) = @_;
-  
+
   assert_exists  $option => 'for_each_row_do';
-  
+
   assert_listref $option->{on_columns_heads_named} if exists $option->{on_columns_heads_named};
   assert_listref $option->{on_columns_heads_like}  if exists $option->{on_columns_heads_like};
-    
+
   my $match = $option->{on_columns_heads_named} ? sub { $_[0] eq $_[1] } : sub { $_[0] =~ $_[1] };
   my $targets;
   if ( $option->{on_columns_heads_named} || $option->{on_columns_heads_like} ) {
@@ -143,32 +146,32 @@ sub xlate {
 
   XLATE_LOOP : for my $sheet ( $self->book_id->worksheets ) {
     my $sheet_name = $sheet->get_name;
-    
+
     next if $option->{on_sheet_named}   && $sheet_name ne $option->{on_sheet_named};
     next if $option->{on_sheets_like}   && $sheet_name !~ $option->{on_sheets_like};
     next if $option->{on_sheets_unlike} && $sheet_name =~ $option->{on_sheets_unlike};
-    
+
     my ( $row_min, $row_max ) = $sheet->row_range;
     my ( $col_min, $col_max ) = $sheet->col_range;
-    
+
     my @rows = $row_min .. $row_max;
     my @cols = $col_min .. $col_max;
-    
+
     if ( $targets ) {
       my @matching_cols;
-      
+
       for my $target ( @$targets ) {
-        push @matching_cols, map { $_->[0] } grep { $match->( $_->[1]->value, $target ) } map { [ $_, $sheet->get_cell ( $row_min, $_ ) ] } @cols;
+        push @matching_cols, map { $_->[0] } grep { $match->( $_->[1]->value, $target ) } grep { defined $_->[1] } map { [ $_, $sheet->get_cell ( $row_min, $_ ) ] } @cols;
       }
-      
+
       @cols = @matching_cols;
     }
-    
+
     for my $row ( @rows ) {
       $option->{for_each_row_do}->( $sheet, $row, [ map { $_ ? $_->value : '' } map { $sheet->get_cell ( $row, $_ ) } @cols ] );
     }
   }
-  
+
   $self;
 }
 
@@ -182,7 +185,7 @@ Accessor to L<Spreadsheet::ParseExcel::Workbook> instance ID.
 
 sub book_id {
   my ( $self ) = @_;
-  
+
   $self->{book_id};
 }
 
